@@ -1,7 +1,7 @@
 modavgpred <- function(cand.set, modnames, newdata, type = "response", c.hat = 1,
                        gamdisp = NULL, second.ord = TRUE, nobs = NULL, uncond.se = "revised", parm.type = NULL){
   results <- NULL
-  known <- rep(0, 4) #create an identifier of class type for lm, glm, lme, mer, and unmarked
+  known <- rep(0, 5) #create an identifier of class type for lm, glm, lme, mer, and unmarked
   ##extract classes
   mod.class <- unlist(lapply(X = cand.set, FUN = class))
   ##check if all are identical
@@ -39,6 +39,13 @@ modavgpred <- function(cand.set, modnames, newdata, type = "response", c.hat = 1
     known[4] <- 1
   }
 
+  ##determine if gls
+  if(identical(check.class, "gls"))  {
+    results <- modavgpred.gls(cand.set = cand.set, modnames = modnames, newdata = newdata,
+                          second.ord = second.ord, nobs = nobs, uncond.se = uncond.se)
+    known[5] <- 1
+  }
+  
   ##warn if class is neither lm, glm, nor lme
   if(sum(known) < 1) {stop("Function not yet defined for this object class")}
   
@@ -492,6 +499,113 @@ modavgpred.mer <- function(cand.set, modnames, newdata, type = "response", c.hat
 
 
 
+modavgpred.gls <-
+function(cand.set, modnames, newdata, second.ord = TRUE,
+         nobs = NULL, uncond.se = "revised") {
+  ##newdata is data frame with exact structure of the original data frame (same variable names and type)
+
+  ##check if object is of "lm" or "glm" class
+  ##extract classes
+  mod.class <- unlist(lapply(X = cand.set, FUN = class))
+  ##check if all are identical
+  check.class <- unique(mod.class)
+
+  if(identical(check.class, "gls") )  {
+
+    ##determine number of observations in new data set
+    nobserv <- dim(newdata)[1]
+
+    ##determine number of columns in new data set
+    ncolumns <- dim(newdata)[2]
+
+    ##if only 1 column, add an additional column to avoid problems in computation with predictSE.mer( )
+    if(ncolumns == 1) newdata$blank.fake.column.NAs <- NA
+ 
+    ##store AICc table
+    AICctab<-aictab(cand.set=cand.set, modnames=modnames, second.ord=second.ord, nobs=nobs, sort=FALSE)
+
+    ##create object to hold Model-averaged estimates and unconditional SE's
+    Mod.avg.out<-matrix(NA, nrow=nobserv, ncol=2)
+    colnames(Mod.avg.out)<-c("Mod.avg.est", "Uncond.SE")
+
+
+
+
+    ##begin loop - AICc
+    if(second.ord==TRUE){
+      for (obs in 1:nobserv) {
+
+        ##extract fitted value for observation obs
+        fit<-unlist(lapply(X=cand.set, FUN=function(i)predictSE.gls(i, se.fit=TRUE, newdata=newdata[obs, ])$fit))
+
+        ##extract SE for fitted value for observation obs
+        SE<-unlist(lapply(X=cand.set, FUN=function(i)predictSE.gls(i, se.fit=TRUE, newdata=newdata[obs, ])$se.fit))
+
+
+        ##create temporary data.frame to store fitted values and SE 
+        AICctmp<-AICctab
+        AICctmp$fit<-fit
+        AICctmp$SE<-SE
+
+        ##compute model averaged prediction and store in output matrix
+        Mod.avg.out[obs, 1]<-sum(AICctmp$AICcWt*AICctmp$fit)
+        ##compute unconditional SE and store in output matrix
+
+        ##unconditional SE based on equation 4.9 of Burnham and Anderson 2002
+        if(identical(uncond.se, "old")) {
+          Mod.avg.out[obs, 2]<-sum(AICctmp$AICcWt*sqrt(AICctmp$SE^2 + (AICctmp$fit- Mod.avg.out[obs, 1])^2))
+        }
+
+        ##revised computation of unconditional SE based on equation 6.12 of Burnham and Anderson 2002; Anderson 2008, p. 111
+        if(identical(uncond.se, "revised")) {
+          Mod.avg.out[obs, 2]<-sqrt(sum(AICctmp$AICcWt*(AICctmp$SE^2 + (AICctmp$fit- Mod.avg.out[obs, 1])^2)))
+        }
+      }
+    }
+
+
+
+    ##create temporary data.frame to store fitted values and SE - AIC
+    if(second.ord==FALSE) {
+      for (obs in 1:nobserv) {
+
+        ##extract fitted value for observation obs
+        fit<-unlist(lapply(X=cand.set, FUN=function(i)predictSE.gls(i, se.fit=TRUE, newdata=newdata[obs, ])$fit))
+        ##extract SE for fitted value for observation obs
+        SE<-unlist(lapply(X=cand.set, FUN=function(i)predictSE.gls(i, se.fit=TRUE, newdata=newdata[obs, ])$se.fit))
+
+        AICtmp<-AICctab
+        AICtmp$fit<-fit
+        AICtmp$SE<-SE
+
+        ##compute model averaged prediction and store in output matrix
+        Mod.avg.out[obs, 1]<-sum(AICtmp$AICWt*AICtmp$fit)
+
+        ##compute unconditional SE and store in output matrix
+        ##unconditional SE based on equation 4.9 of Burnham and Anderson 2002
+        if(identical(uncond.se, "old")) {
+          Mod.avg.out[obs, 2]<-sum(AICtmp$AICWt*sqrt(AICtmp$SE^2 + (AICtmp$fit- Mod.avg.out[obs, 1])^2))
+        }
+
+        ##revised computation of unconditional SE based on equation 6.12 of Burnham and Anderson 2002; Anderson 2008, p. 111
+        if(identical(uncond.se, "revised")) {
+          Mod.avg.out[obs, 2]<-sqrt(sum(AICtmp$AICWt*(AICtmp$SE^2 + (AICtmp$fit- Mod.avg.out[obs, 1])^2)))
+        }  
+        
+      }
+    }
+
+
+
+    Mod.pred.list <- list("mod.avg.pred" = Mod.avg.out[,1], "uncond.se" = Mod.avg.out[,2])
+    class(Mod.pred.list) <- c("modavgpred", "list")
+    return(Mod.pred.list)
+    
+  } else {stop("This function is only appropriate with \'gls\' class\n")}
+}
+
+
+
 
 
 
